---------------------------------------------------------
------- GLOBAL ADDON SETTINGS --
---------------------------------------------------------
RidinDirtyLite = {
	name = "RidinDirtyLite",
	author = "@sinnereso",
	version = "2024.06.29",
	svName = "RidinDirtyLiteVars",
	svVersion = 1,
	logo = "|c6666FF[RDL]|r",
	errSnd = "PlayerAction_NotEnoughMoney",
	mailSnd = "New_Mail",
	eventSnd = "GroupElection_ResultWon",
	hasPassenger = false,
	passengerName = "",
}
---------------------------------------------------------
--------- ADDON LOADED --
---------------------------------------------------------
function RidinDirtyLite.AddOnLoaded(eventCode, addOnName)
	if RidinDirty ~= nil then EVENT_MANAGER:UnregisterForEvent("RidinDirtyLite", EVENT_ADD_ON_LOADED) return end
	if addOnName ~= "RidinDirtyLite" then return end
	ZO_CreateStringId("SI_BINDING_NAME_RIDINDIRTYLITE_MOUNT_PLAYER", "Mount Group Member")
	EVENT_MANAGER:UnregisterForEvent("RidinDirtyLite", EVENT_ADD_ON_LOADED)
	RidinDirtyLite.Initialize()--<< INITIALIZE VARIABLES
end
---------------------------------------------------------
------- INITIALIZE AFTER ADDON LOADED --
---------------------------------------------------------
function RidinDirtyLite.Initialize()
	local defaultSavedVars = {
		mountOnScreen = false,
	}
	RidinDirtyLite.savedVariables = ZO_SavedVars:NewAccountWide( RidinDirtyLite.svName, RidinDirtyLite.svVersion, nil, defaultSavedVars )
	EVENT_MANAGER:RegisterForEvent("RidinDirtyLite", EVENT_MOUNTED_STATE_CHANGED, RidinDirtyLite.MountedStateChange)
	EVENT_MANAGER:RegisterForEvent("RidinDirtyLite", EVENT_PLAYER_ACTIVATED, RidinDirtyLite.PlayerActivated)
	--Addon Load Complete --
end
---------------------------------------------------------
-------- PLAYER ACTIVATED --
---------------------------------------------------------
function RidinDirtyLite.PlayerActivated()
	RidinDirtyLite.PassengerStateChange()
end
---------------------------------------------------------
-------- MOUNT GROUP MEMBER --
---------------------------------------------------------
function RidinDirtyLite.MountPlayer()
	local displayNamePref = nil
	local isMountable = false
	if IsUnitDeadOrReincarnating("player") or IsUnitInCombat("player") or IsMounted() or HasPendingCompanion() then
		PlaySound(RidinDirtyLite.errSnd)
		df(RidinDirtyLite.logo .. " Unable to mount player right now")
		return
	end
	for iD = 1, GetGroupSize() do
		local playerID = GetGroupUnitTagByIndex(iD)
		local playerCharName = GetUnitName(playerID)
		local playerDisplayName = GetUnitDisplayName(playerID)
		local mountedState, hasEnabledGroupMount, hasFreePassengerSlot = GetTargetMountedStateInfo(playerDisplayName)
		if mountedState == MOUNTED_STATE_MOUNT_RIDER and hasEnabledGroupMount and hasFreePassengerSlot then isMountable = true else isMountable = false end
		if not ZO_ShouldPreferUserId() then displayNamePref = playerCharName else displayNamePref = playerDisplayName end
		displayNamePref = zo_strformat("<<1>>", displayNamePref)--<< Strip genders
		if playerDisplayName ~= GetUnitDisplayName("player") and IsUnitOnline(playerID) and IsUnitInGroupSupportRange(playerID) and isMountable and RidinDirtyLite.DistanceToUnit(playerID) < 5.0 then
			df(RidinDirtyLite.logo .. " Mounting " .. displayNamePref)
			UseMountAsPassenger(playerDisplayName)
			return
		end
	end
	PlaySound(RidinDirtyLite.errSnd)
	df(RidinDirtyLite.logo .. " No player in group mountable")
end

function RidinDirtyLite.MountedStateChange(eventCode, isMounted)--<< CHECK FOR MULTI-RIDER MOUNT
	local mountedState, hasEnabledGroupMount, hasFreePassengerSlot = GetTargetMountedStateInfo(GetUnitDisplayName("player"))
	if mountedState == MOUNTED_STATE_MOUNT_RIDER and hasEnabledGroupMount then RidinDirtyLite.PassengerStateChange() end
end

function RidinDirtyLite.PassengerStateChange()--<< LOOP FOR PASSENGER STATE CHANGE
	local mountedState, hasEnabledGroupMount, hasFreePassengerSlot = GetTargetMountedStateInfo(GetUnitDisplayName("player"))
	if mountedState ~= MOUNTED_STATE_MOUNT_RIDER then
		RidinDirtyLite.hasPassenger = false
	elseif mountedState == MOUNTED_STATE_MOUNT_RIDER and hasEnabledGroupMount and hasFreePassengerSlot and RidinDirtyLite.hasPassenger then
		RidinDirtyLite.hasPassenger = false if not RidinDirtyLite.savedVariables.mountOnScreen then PlaySound(RidinDirtyLite.mailSnd)
			df(RidinDirtyLite.logo .. " " .. tostring(RidinDirtyLite.passengerName) .. " has exited") else
				CENTER_SCREEN_ANNOUNCE:AddMessage( 0, CSA_CATEGORY_SMALL_TEXT, RidinDirtyLite.mailSnd, (RidinDirtyLite.logo .. " |cC99912" .. tostring(RidinDirtyLite.passengerName) .. " has exited|r"), nil, nil, nil, nil, nil, 3000, nil) end
	elseif mountedState == MOUNTED_STATE_MOUNT_RIDER and hasEnabledGroupMount and not hasFreePassengerSlot and not RidinDirtyLite.hasPassenger then
		RidinDirtyLite.hasPassenger = true if not RidinDirtyLite.savedVariables.mountOnScreen then PlaySound(RidinDirtyLite.mailSnd)
			df(RidinDirtyLite.logo .. " " .. tostring(RidinDirtyLite.GetPassengerName()) .. " is RidinDirty") else
				CENTER_SCREEN_ANNOUNCE:AddMessage( 0, CSA_CATEGORY_SMALL_TEXT, RidinDirtyLite.mailSnd, (RidinDirtyLite.logo .. " |cC99912" .. tostring(RidinDirtyLite.GetPassengerName()) .. " is RidinDirty|r"), nil, nil, nil, nil, nil, 3000, nil) end
	end
	if mountedState == MOUNTED_STATE_MOUNT_RIDER and hasEnabledGroupMount then zo_callLater(function() RidinDirtyLite.PassengerStateChange() end, 1000) end
end

function RidinDirtyLite.GetPassengerName()
	local displayNamePref = nil
	for iD = 1, GetGroupSize() do
		local playerID = GetGroupUnitTagByIndex(iD)
		local playerCharName = GetUnitName(playerID)
		local playerDisplayName = GetUnitDisplayName(playerID)
		local mountedState, hasEnabledGroupMount, hasFreePassengerSlot = GetTargetMountedStateInfo(playerDisplayName)
		if mountedState == MOUNTED_STATE_MOUNT_PASSENGER and RidinDirtyLite.DistanceToUnit(playerID) < 0.1 then
			if not ZO_ShouldPreferUserId() then displayNamePref = playerCharName else displayNamePref = playerDisplayName end
			displayNamePref = zo_strformat("<<1>>", displayNamePref)--<< Strip genders
			RidinDirtyLite.passengerName = displayNamePref
			return displayNamePref
		end
	end
	return "uknown"
end

function RidinDirtyLite.DistanceToUnit(unitID)--<< DISTANCE TO UNITID
	local _, selfX, selfY, selfH = GetUnitWorldPosition("player")
	local _, targetX, targetY, targetH = GetUnitWorldPosition(unitID)
	local nDistance = zo_distance3D(targetX, targetY, targetH, selfX, selfY, selfH) / 100
	return nDistance
end

if not RidinDirty then
	SLASH_COMMANDS["/rdl"] = function (option) if not RidinDirtyLite.savedVariables.mountOnScreen then
		RidinDirtyLite.savedVariables.mountOnScreen = true df(RidinDirtyLite.logo .. " On Screen Enabled") else
		RidinDirtyLite.savedVariables.mountOnScreen = false df(RidinDirtyLite.logo .. " On Screen Disabled") end
	end
end
EVENT_MANAGER:RegisterForEvent("RidinDirtyLite", EVENT_ADD_ON_LOADED, RidinDirtyLite.AddOnLoaded)